********************************************************************************
* By: Diego Parra 
* Figure 4.1
*******************************************************************************
*---------------------------------------------------------------------
* EMPLOYMENT RATE BY COUNTRY INCOME GROUP
* Figure 4.1.  Worldwide, employment fell sharply during the pandemic 
*---------------------------------------------------------------------

clear all 
set more off
cap log close

** Import data
use "$dt_ch4/employment_world.dta", clear  

/* The main data source is Thomson Reuters (Datastream). 
The data is confidential and was complemented with employment 
and working-age population data from the ILO and national sources. */

*** Create quarterly date
gen year = substr(DATEQ,1,4)
gen quarter = substr(DATEQ,6,1)
destring year quarter, replace
gen dateq = yq(year, quarter)
format dateq %tq

*** Prepare data
drop if INC == ""
keep if dateq >= tq(2012q1) & dateq <= tq(2021q3)

gen inc_code = "_li" if INC == "Low Income"  
replace inc_code = "_lmi" if INC == "Lower Middle Income"  
replace inc_code = "_umi" if INC == "Upper Middle Income"  
replace inc_code = "_hi" if INC == "High Income"  
drop INC

*** Calculate weighted average
****Only countries with at least 7 non-missing data points are considered.

collapse (mean) emp_rate ///
if non_miss_emp >= 7 [iw = LP], by(inc_code dateq)

reshape wide emp_rate, i(dateq) j(inc_code) string

*** Percentage point changes vis a vis 2019Q4
tset dateq, quarterly

global vars "emp_rate_hi emp_rate_li emp_rate_lmi emp_rate_umi"
foreach v of global vars {
	gen `v'_2019_aux = `v' if dateq == tq(2019q4)
	egen `v'_2019 = mode(`v'_2019_aux)
	gen pp_`v' = 100*(`v' - `v'_2019)
	gen p_`v' = 100*(`v' - `v'_2019) / `v'_2019
	drop `v'_2019_aux `v'_2019
}  

*** Graph
graph set window fontface "Calibri Light"

twoway (line pp_emp_rate_lmi dateq, lp(solid) lc("236 110 109") lw(*1.5)) ///
(line pp_emp_rate_umi dateq, lp(solid) lc("239 165 100") lw(*1.5)) ///
(line pp_emp_rate_hi dateq, lp(solid) lc("101 188 160") lw(*1.5)) ///
if dateq >= tq(2019q4), ///
legend(pos(6) rows(1) order(1 "Lower-middle-income" ///
2 "Upper-middle-income" 3 "High-income") ///
size(small)  symxsize(medium)) ///
yline(0) ///
tlabel(2019q4(1)2021q3) ///
title("Figure 4.1 Worldwide, employment fell sharply during the pandemic", ///
size(medium)) ///
subtitle("Change in employment rate, by country income group, 2019:Q4–2021:Q3", ///
size(small)) ///
ytitle("Average change in employment rate (percentage points)", size(small)) ///
xtitle("") ///
xlabel(, nogrid) ylab(-10(2)6, nogrid) legend(on)

gr export "${out_ch4}/Ch4_Fig1_Worldwide employment.wmf", replace
